summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/fmopl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/fmopl.cpp')
-rw-r--r--src/devices/sound/fmopl.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/devices/sound/fmopl.cpp b/src/devices/sound/fmopl.cpp
index 9f3a92a4517..ccd9f4199a0 100644
--- a/src/devices/sound/fmopl.cpp
+++ b/src/devices/sound/fmopl.cpp
@@ -2101,8 +2101,8 @@ static unsigned char OPLRead(FM_OPL *OPL,int a)
case 0x1a: /* PCM-DATA */
if(OPL->type&OPL_TYPE_ADPCM)
{
- OPL->device->logerror("Y8950 A/D convertion is accessed but not implemented !\n");
- return 0x80; /* 2's complement PCM data - result from A/D convertion */
+ OPL->device->logerror("Y8950 A/D conversion is accessed but not implemented !\n");
+ return 0x80; /* 2's complement PCM data - result from A/D conversion */
}
return 0;
}